@@ -48,7 +48,7 @@
 #' * an `inla.mesh.2d` object for continuous 2D integration.
 #' @param name Character array stating the name of the domains dimension(s).
 #' If `NULL`, the names are taken from coordinate names from `samplers` for
-#' `Spatial*` objects, otherwise "x", "y", "coordinateZ" for 2D regions and
+#' `Spatial*` objects, otherwise "x", "y", "z" for 2D regions and
 #' `"x"` for 1D regions
 #' @param group Column names of the `samplers` object (if applicable) for which
 #' the integration points are calculated independently and not merged when
@@ -72,7 +72,6 @@
 #' \donttest{
 #' if (require("INLA", quietly = TRUE) &&
 #'   require("ggplot2", quietly = TRUE)) {
-#'
 #'   # Create 50 integration points covering the dimension 'myDim' between 0 and 10.
 #'
 #'   ips <- ipoints(c(0, 10), 50, name = "myDim")
@@ -155,6 +154,11 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
     samplers <- NULL
   }
 
+  samplers_is_sf <- inherits(samplers, c("sf", "sfc"))
+  if (samplers_is_sf) {
+    samplers <- as(samplers, "Spatial")
+  }
+
   is_2d <-
     (
       !is.null(samplers) &&
@@ -310,7 +314,7 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
   } else if (inherits(domain, "inla.mesh") &&
     is.null(samplers) &&
     identical(int.args[["method"]], "stable")) {
-    coord_names <- c("x", "y", "coordinateZ")
+    coord_names <- c("x", "y", "z")
     if (!is.null(name)) {
       coord_names[seq_along(name)] <- name
     }
@@ -318,15 +322,15 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
     # transform to equal area projection
     if (!fm_crs_is_null(domain$crs)) {
       crs <- domain$crs
-      samplers <- stransform(domain, crs = CRS("+proj=cea +units=km"))
+      samplers <- fm_transform(domain, crs = fm_crs("+proj=cea +units=km"))
     }
 
-    ips <- vertices(domain)
+    ips <- vertices.inla.mesh(domain)
     ips$weight <- INLA::inla.mesh.fem(domain, order = 1)$va
 
     # backtransform
     if (!fm_crs_is_null(domain$crs)) {
-      ips <- stransform(ips, crs = crs)
+      ips <- fm_transform(ips, crs = crs)
     }
     coordnames(ips) <- coord_names[seq_len(NCOL(coordinates(ips)))]
   } else if (inherits(samplers, "SpatialPointsDataFrame")) {
@@ -341,7 +345,6 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
     ips$weight <- 1
   } else if (inherits(samplers, "SpatialLines") ||
     inherits(samplers, "SpatialLinesDataFrame")) {
-
     # If SpatialLines are provided convert into SpatialLinesDataFrame and attach weight = 1
     if (inherits(samplers, "SpatialLines") &&
       !inherits(samplers, "SpatialLinesDataFrame")) {
@@ -363,7 +366,7 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
       project = identical(int.args[["method"]], "stable")
     )
 
-    coord_names <- c("x", "y", "coordinateZ")
+    coord_names <- c("x", "y", "z")
     if (!is.null(coordnames(samplers))) {
       coord_names[seq_along(coordnames(samplers))] <- coordnames(samplers)
     } else if (!is.null(name)) {
@@ -395,7 +398,7 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
 
     # Convert samplers and domain to equal area CRS
     if (!fm_crs_is_null(domain$crs)) {
-      samplers <- stransform(samplers, crs = sp::CRS("+proj=cea +units=km"))
+      samplers <- fm_transform(samplers, crs = fm_crs("+proj=cea +units=km"))
     }
 
     # This old code doesn't handle holes properly.
@@ -430,10 +433,12 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
       domain$crs <- fm_sp_get_crs(samplers)
     } else {
       if (!fm_crs_is_null(domain$crs)) {
-        domain <- stransform(domain, crs = CRS("+proj=cea +units=km"))
+        domain <- fm_transform(domain, crs = fm_crs("+proj=cea +units=km"))
       }
     }
-    domain_crs <- fm_ensure_crs(domain$crs)
+    domain_crs <- fm_crs(domain$crs)
+    domain_crs <- fm_CRS(domain_crs)
+
 
     if (identical(int.args[["poly_method"]], "legacy")) {
       ips <- int.polygon(domain,
@@ -442,7 +447,7 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
       )
     } else {
       if (!is.null(int.args$use_new) && !int.args$use_new) {
-        ips <- bru_int_polygon(
+        ips <- bru_int_polygon_old(
           domain,
           polylist = poly_segm,
           method = int.args$method,
@@ -451,7 +456,6 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
       } else {
         ips <- bru_int_polygon(
           domain,
-          polylist = poly_segm,
           method = int.args$method,
           nsub = int.args$nsub2,
           samplers = samplers
@@ -464,23 +468,23 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
       samplers@data[ips$group, group, drop = FALSE],
       weight = ips[, "weight"] * samplers@data[ips$group, "weight"]
     )
-    if (is.null(ips$coordinateZ)) {
-      ips <- SpatialPointsDataFrame(ips[, c("x", "y")],
+    if (is.null(ips$z)) {
+      ips <- sp::SpatialPointsDataFrame(ips[, c("x", "y")],
         data = df,
         match.ID = FALSE, proj4string = domain_crs
       )
     } else {
-      ips <- SpatialPointsDataFrame(ips[, c("x", "y", "coordinateZ")],
+      ips <- sp::SpatialPointsDataFrame(ips[, c("x", "y", "z")],
         data = df,
         match.ID = FALSE, proj4string = domain_crs
       )
     }
 
     if (!fm_crs_is_null(domain_crs) && !fm_crs_is_null(samplers_crs)) {
-      ips <- stransform(ips, crs = samplers_crs)
+      ips <- fm_transform(ips, crs = samplers_crs)
     }
 
-    coord_names <- c("x", "y", "coordinateZ")
+    coord_names <- c("x", "y", "z")
     if (!is.null(coordnames(samplers))) {
       coord_names[seq_along(coordnames(samplers))] <- coordnames(samplers)
     } else if (!is.null(name)) {
@@ -491,6 +495,10 @@ ipoints <- function(samplers = NULL, domain = NULL, name = NULL, group = NULL,
     stop("No integration handling code reached; please notify the package developer.")
   }
 
+  if (samplers_is_sf && inherits(ips, "Spatial")) {
+    ips <- sf::st_as_sf(ips)
+  }
+
   ips
 }
 
@@ -639,6 +647,11 @@ ipmaker <- function(samplers, domain, dnames,
     ips <- ipoints(samplers, domain$coordinates,
       group = samp.dim, int.args = int.args
     )
+  } else if (inherits(samplers, c("sf", "sfc")) && ("geometry" %in% dnames)) {
+    ips <- ipoints(samplers, domain$geometry,
+      group = setdiff(samp.dim, "geometry"),
+      int.args = int.args
+    )
   } else {
     ips <- NULL
   }
@@ -667,21 +680,25 @@ vertex.projection <- function(points, mesh, columns = names(points), group = NUL
   if (is.null(group) || (length(group) == 0)) {
     res <- INLA::inla.fmesher.smorg(mesh$loc, mesh$graph$tv, points2mesh = coordinates(points))
     tri <- res$p2m.t
+    ok <- tri > 0
+    if (any(!ok)) {
+      warning("Some integration points were outside the mesh; check your coordinate systems.")
+    }
 
     data <- list()
     for (k in seq_along(columns)) {
       cn <- columns[k]
-      nw <- points@data[, columns] * res$p2m.b
-      w.by <- by(as.vector(nw), as.vector(mesh$graph$tv[tri, ]), sum, simplify = TRUE)
+      nw <- points@data[ok, cn] * res$p2m.b[ok, , drop = FALSE]
+      w.by <- by(as.vector(nw), as.vector(mesh$graph$tv[tri[ok], ]), sum, simplify = TRUE)
       data[[cn]] <- as.vector(w.by)
     }
 
     data <- data.frame(data)
-    coords <- mesh$loc[as.numeric(names(w.by)), , drop = FALSE]
+    coords <- mesh$loc[as.numeric(names(w.by)), seq_along(coordnames(points)), drop = FALSE]
     data$vertex <- as.numeric(names(w.by))
 
-    ret <- SpatialPointsDataFrame(coords,
-      proj4string = fm_sp_get_crs(points),
+    ret <- sp::SpatialPointsDataFrame(coords,
+      proj4string = fm_CRS(points),
       data = data,
       match.ID = FALSE
     )
@@ -691,7 +708,7 @@ vertex.projection <- function(points, mesh, columns = names(points), group = NUL
     # and set their projected data according to `fill`
 
     if (!is.null(fill)) {
-      vrt <- vertices(mesh)
+      vrt <- vertices.inla.mesh(mesh)
       vrt <- vrt[setdiff(vrt$vertex, data$vertex), ]
       if (nrow(vrt) > 0) {
         for (nm in setdiff(names(data), "vertex")) vrt[[nm]] <- fill
