@@ -47,7 +47,6 @@ NULL
 #'
 
 import.seals <- function(sealfile = "WestIce2012.csv", icefile = "reflectance_0.0025deg_grid_modis_20120328_1310.tif") {
-
   #' Load seal data
 
   seals <- read.csv(sealfile)
@@ -64,7 +63,7 @@ import.seals <- function(sealfile = "WestIce2012.csv", icefile = "reflectance_0.
   #' Change CRS
 
   target.p4s <- "+proj=utm +zone=27 +units=km"
-  seals <- spTransform(seals, CRS(target.p4s))
+  seals <- fm_transform(seals, fm_crs(target.p4s))
   coordnames(seals) <- c("x", "y")
 
   #' Select a strip
@@ -96,7 +95,7 @@ import.seals <- function(sealfile = "WestIce2012.csv", icefile = "reflectance_0.
   #' Ice Covariate
 
   ice <- rgdal::readGDAL(icefile)
-  ice <- spTransform(ice, CRS(target.p4s))
+  ice <- fm_transform(ice, fm_crs(target.p4s))
   ii <- is.inside(mesh, coordinates(ice))
   ice <- ice[as.vector(ii), ]
 
