@@ -1,5 +1,5 @@
 \donttest{
-if (bru_safe_inla()) {
+if (bru_safe_inla() && require(ggplot2, quietly = TRUE)) {
   # Generate some data
 
   input.df <- data.frame(x = cos(1:10))
@@ -74,4 +74,4 @@ if (bru_safe_inla()) {
     gg(xipost) +
     gg(xipost, mapping = aes(y = median), ribbon = FALSE, color = "red")
 }
-}
\ No newline at end of file
+}
